( cd usr/bin ; rm -rf jed-script )
( cd usr/bin ; ln -sf jed jed-script )
( cd usr/doc ; rm -rf jed-0.99-18 )
( cd usr/doc ; ln -sf /usr/share/jed jed-0.99-18 )
( cd usr/share/jed ; rm -rf info )
( cd usr/share/jed ; ln -sf /usr/info info )
